﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Data;
using System.Threading;
using System.Windows.Threading;
using System.Runtime.InteropServices;
using System.IO;
using System.Text.RegularExpressions;
using System.Xml.Linq;
using System.Globalization;
using System.Diagnostics;
using Stimulsoft.Report;

namespace ReportSample
{
    public partial class MainWindow : Window
    {
        //Explanation: 
        //When reports are shown in the same thread, they are not responsive any more, when you open a different window with ShowDialog()
        //When you show the reports in an own thread, they stay responsive
        //Problem: on the 2nd call of 'ShowReport', an exception is thrown, no matter if 1st call was in same or in new thread
        //Version is 2022.4.5.0

        public MainWindow()
        {
            InitializeComponent();

        }

        public class DataItem
        {
            public int ID { get; set; }
            public string Name { get; set; }
        }

        private StiReport GetReport()
        {
            StiReport rpt = new StiReport();
            rpt.Load("Report.mrt");

            List<DataItem> dataItems = new List<DataItem>();
            dataItems.Add(new DataItem() { ID = 1, Name = "XXX" });
            dataItems.Add(new DataItem() { ID = 2, Name = "YYY" });
            dataItems.Add(new DataItem() { ID = 3, Name = "ZZZ" });

            rpt.RegData("Datasource", dataItems);
            rpt.RenderWithWpf(false);

            return rpt;
        }

        private void btnShowReportSameThread_Click(object sender, RoutedEventArgs e)
        {
            var rpt = GetReport();
            rpt.ShowWithWpf(false);
        }

        private void btnShowReportNewThread_Click(object sender, RoutedEventArgs e)
        {
            var rpt = GetReport();
            ShowReport(rpt);
        }

        public static void ShowReport(StiReport rpt)
        {
            Thread threadShowReport = new Thread(new ParameterizedThreadStart(ShowReport));
            threadShowReport.SetApartmentState(ApartmentState.STA);
            threadShowReport.IsBackground = true;
            threadShowReport.Start(rpt);
        }

        public static void ShowReport(object obj)
        {
            try
            {
                ((StiReport)obj).ShowWithWpf(true);
            }
            catch (System.Exception ex)
            {
                System.Windows.MessageBox.Show($"{ex.Message} {Environment.NewLine}{ex.InnerException}");
            }
        }

        private void btnChildWindow_Click(object sender, RoutedEventArgs e)
        {
            ChildWindow w = new ChildWindow();
            w.Owner = this;
            w.ShowDialog();
        }



    }


}
